Fileformats
============

Python classes for representing different file formats for use in type hinting in data workflows

Quick Installation
------------------

The ``fileformats`` is a metapackage that installs all centrally supported sub-packages:

* `fileformats-core <https://github.com/ArcanaFramework/fileformats-core>`__
* `fileformats-common <https://github.com/ArcanaFramework/fileformats-common>`__
* `fileformats-medimage <https://github.com/ArcanaFramework/fileformats-medimage>`__


The metapackage can be installed for Python 3 using *pip*::

    $ pip3 install fileformats


License
-------

This work is licensed under a
`Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License <http://creativecommons.org/licenses/by-nc-sa/4.0/>`_

.. image:: https://i.creativecommons.org/l/by-nc-sa/4.0/88x31.png
  :target: http://creativecommons.org/licenses/by-nc-sa/4.0/
  :alt: Creative Commons License: Attribution-NonCommercial-ShareAlike 4.0 International

|

*Note: For the legacy version of Arcana as described in
Close TG, et. al. Neuroinformatics. 2020 18(1):109-129. doi:* `<10.1007/s12021-019-09430-1>`_
*please see* `<https://github.com/MonashBI/arcana-legacy>`_.
*Conceptually, the legacy version and the versions in this repository (>=2) are similar.
However, instead of Nipype, v2 uses the Pydra workflow engine (Nipype's successor)
and the syntax has been rewritten from scratch to make it more streamlined and intuitive.*
